summaryrefslogtreecommitdiff
path: root/src/core/model/Domain.hpp
diff options
context:
space:
mode:
authorBenjamin Paassen <bpaassen@techfak.uni-bielefeld.de>2015-01-16 12:31:06 +0100
committerBenjamin Paassen <bpaassen@techfak.uni-bielefeld.de>2015-01-16 12:31:06 +0100
commit8cf24170a4998e316c1b9c9bfd2b56e266c544cd (patch)
treef795906bafc9c904fed92c5c6c9942e4d3285c36 /src/core/model/Domain.hpp
parent7bdaa89ccef864d36f1e1adce535179d9e5fadce (diff)
renamed isa to superclass in Domain::Descriptor and id some cosmetic changes.
Diffstat (limited to 'src/core/model/Domain.hpp')
-rw-r--r--src/core/model/Domain.hpp15
1 files changed, 7 insertions, 8 deletions
diff --git a/src/core/model/Domain.hpp b/src/core/model/Domain.hpp
index 791d563..8bc21e9 100644
--- a/src/core/model/Domain.hpp
+++ b/src/core/model/Domain.hpp
@@ -546,7 +546,7 @@ typedef RangeSet<size_t> Cardinality;
class StructuredClass : public Descriptor {
private:
const Cardinality cardinality;
- Owned<StructuredClass> isa;
+ Owned<StructuredClass> superclass;
NodeVector<StructuredClass> subclasses;
public:
@@ -570,7 +570,7 @@ public:
* @param attributesDescriptor is a StructType that specifies the attribute
* keys as well as value domains for this
* Descriptor.
* @param isa references a parent StructuredClass. Please
* look for more information on inheritance in
* the class documentation above. The default is
* a null reference, meaning no super class.
@@ -585,7 +585,7 @@ public:
const Cardinality &cardinality,
Handle<StructType> attributesDescriptor = nullptr,
// TODO: What would be a wise default value for isa?
- Handle<StructuredClass> isa = nullptr,
+ Handle<StructuredClass> superclass = nullptr,
bool transparent = false, bool root = false);
/**
@@ -596,13 +596,12 @@ public:
const Cardinality &getCardinality() const { return cardinality; }
/**
* Returns the parent of this StructuredClass in the class inheritance
* hierarchy (!). This is not the same as the parents in the Structure Tree!
*
- * @return the parent of this StructuredClass in the class inheritance
- * hierarchy (!).
+ * @return the superclass of this StructuredClass.
*/
- Rooted<StructuredClass> getIsA() const { return isa; }
+ Rooted<StructuredClass> getSuperclass() const { return superclass; }
/**
* Returns the StructuredClasses that are subclasses of this class. This
@@ -570,7 +570,7 @@ public:
* keys as well as value domains for this
* Descriptor.
- * @param isa references a parent StructuredClass. Please
+ * @param superclass references a parent StructuredClass. Please
* look for more information on inheritance in
* the class documentation above. The default is
@@ -596,13 +596,12 @@ public:
const Cardinality &getCardinality() const { return cardinality; }
/**
- * Returns the parent of this StructuredClass in the class inheritance
- * hierarchy (!). This is not the same as the parents in the Structure Tree!
+ * Returns the superclass of this StructuredClass. This is not the same as
+ * the parents in the Structure Tree!
*